@@ -1,11 +1,12 @@
 import logging
 import os
 import re
+from configparser import ConfigParser
 from subprocess import SubprocessError
 from time import sleep, time
-from typing import List
 
 import sqlalchemy
+from sqlalchemy import inspect, text
 from sqlalchemy.pool import NullPool
 from wiremind_kubernetes.utils import run_command
 
@@ -19,9 +20,12 @@ class AlembicMigrationHelper:
         alembic_directory_path: str = "/app/alembic",
         alembic_config_file_path: str = "alembic.ini",
         database_url: str,
+        alembic_section_name: str,
         additional_parameters: str = "",
         allow_migration_for_empty_database: bool = False,
         configure: bool = True,
+        # skip_db_checks is used for testing purposes only
+        skip_db_checks: bool = False,
     ):
         if not database_url:
             raise ValueError("database_url not set, not upgrading database.")
@@ -31,29 +35,42 @@ class AlembicMigrationHelper:
         self.additional_parameters = additional_parameters
         self.alembic_directory_path = alembic_directory_path
         self.alembic_config_file_path = alembic_config_file_path
+        self.alembic_section_name = alembic_section_name
+        self.skip_db_checks = skip_db_checks
 
         # Chartreuse will upgrade a PG managed/configured by postgres-operator
         self.is_patroni_postgresql: bool = "CHARTREUSE_PATRONI_POSTGRESQL" in os.environ
-        if self.is_patroni_postgresql:
+        if self.is_patroni_postgresql and not skip_db_checks:
             self.additional_parameters += " -x patroni_postgresql=yes"
             self._wait_postgres_is_configured()
 
         if configure:
             self._configure()
-
-        self.is_migration_needed = self._check_migration_needed()
+        # skip_db_checks is used for testing purposes only
+        if not skip_db_checks:
+            self.is_migration_needed = self._check_migration_needed()
+        else:
+            self.is_migration_needed = False
 
     def _configure(self) -> None:
-        cleaned_url = self.database_url.replace("/", r"\/")
-        command_sq: str = (
-            f"sed -i -e 's/sqlalchemy.url.*=.*/sqlalchemy.url={cleaned_url}/' {self.alembic_config_file_path}"
-        )
-        stdout, _, returncode = run_command(command_sq, cwd=self.alembic_directory_path, return_result=True)
-        if returncode == 0:
-            logger.info("alembic.ini was configured.")
-        else:
-            # To avoid displaying the password. sed can still display a part of the URL
-            raise SubprocessError(f"{command_sq.format(sqlalchemy_url='REDACTED')} has failed: {stdout}")
+        config_path = f"{self.alembic_directory_path}/{self.alembic_config_file_path}"
+
+        # Read the configuration file
+        config = ConfigParser()
+        config.read(config_path)
+
+        # Multi-database configuration: update specific section
+        if not config.has_section(self.alembic_section_name):
+            raise ValueError(f"Section '{self.alembic_section_name}' not found in {self.alembic_config_file_path}")
+
+        # Update the sqlalchemy.url in the specific section
+        config.set(self.alembic_section_name, "sqlalchemy.url", self.database_url)
+
+        # Write the updated configuration back to the file
+        with open(config_path, "w") as f:
+            config.write(f)
+
+        logger.info("alembic.ini was configured for section %s.", self.alembic_section_name)
 
     def _wait_postgres_is_configured(self) -> None:
         """
@@ -64,7 +81,7 @@ class AlembicMigrationHelper:
         wait_timeout = int(os.getenv("CHARTREUSE_ALEMBIC_POSTGRES_WAIT_CONFIGURED_TIMEOUT", 60))
         engine = sqlalchemy.create_engine(self.database_url, poolclass=NullPool, connect_args={"connect_timeout": 1})
 
-        default_privileges_checks: List[str] = [
+        default_privileges_checks: list[str] = [
             "SET ROLE wiremind_owner",  # The real owner, alembic will switch to it before running migrations.
             "CREATE TABLE _chartreuse_test_default_privileges(id serial)",
             "SET ROLE wiremind_writer_user",
@@ -80,7 +97,7 @@ class AlembicMigrationHelper:
                 with engine.connect() as connection:
                     transac = connection.begin()
                     # TODO: Use scalar_one() once sqlachemly >= 1.4
-                    _id = connection.execute(";".join(default_privileges_checks)).scalar()
+                    _id = connection.execute(text(";".join(default_privileges_checks))).scalar()
                     assert _id == 1
                     transac.rollback()
                 logger.info(
@@ -90,7 +107,7 @@ class AlembicMigrationHelper:
                 return
             except Exception as e:
                 # TODO: Learn about exceptions that should be caught here, otherwise we'll wait for nothing
-                logger.info(f"Caught: {e}")
+                logger.info("Caught: %s", e)
                 logger.info(
                     "Waiting for the postgres-operator to create the user wiremind_owner_user"
                     " (that alembic and I use) and to set default privileges..."
@@ -98,15 +115,15 @@ class AlembicMigrationHelper:
                 sleep(2)
         raise Exception(
             f"I'm fed up! Waited {wait_timeout}s for postgres-operator to configure the"
-            f" Postgres database. Start by checking the postgres-operator logs."
+            f" Postgres database. Check the Postgres logs and then postgres-operator for anything fishy."
         )
 
-    def _get_table_list(self) -> List[str]:
-        return sqlalchemy.create_engine(self.database_url).table_names()
+    def _get_table_list(self) -> list[str]:
+        return inspect(sqlalchemy.create_engine(self.database_url)).get_table_names()
 
     def is_postgres_empty(self) -> bool:
         table_list = self._get_table_list()
-        logger.info(f"Tables in the database: {table_list}")
+        logger.info("Tables in the database: %s", table_list)
         # Don't count "alembic" table
         table_name = "alembic_version"
         if table_name in table_list:
